package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.SysMessageRecord;
import com.ruoyi.system.service.ISysMessageRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 消息接收记录Controller
 * 
 * @author haotian
 * @date 2024-11-04
 */
@RestController
@RequestMapping("/system/sysMessageRecord")
public class SysMessageRecordController extends BaseController
{
    @Autowired
    private ISysMessageRecordService sysMessageRecordService;

    /**
     * 查询消息接收记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:sysMessageRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysMessageRecord sysMessageRecord)
    {
        startPage();
        List<SysMessageRecord> list = sysMessageRecordService.selectSysMessageRecordList(sysMessageRecord);
        return getDataTable(list);
    }

    /**
     * 导出消息接收记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:sysMessageRecord:export')")
    @Log(title = "消息接收记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysMessageRecord sysMessageRecord)
    {
        List<SysMessageRecord> list = sysMessageRecordService.selectSysMessageRecordList(sysMessageRecord);
        ExcelUtil<SysMessageRecord> util = new ExcelUtil<SysMessageRecord>(SysMessageRecord.class);
        util.exportExcel(response, list, "消息接收记录数据");
    }

    /**
     * 获取消息接收记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:sysMessageRecord:query')")
    @GetMapping(value = "/{messageRecordId}")
    public AjaxResult getInfo(@PathVariable("messageRecordId") Long messageRecordId)
    {
        return success(sysMessageRecordService.selectSysMessageRecordByMessageRecordId(messageRecordId));
    }

    /**
     * 新增消息接收记录
     */
    @PreAuthorize("@ss.hasPermi('system:sysMessageRecord:add')")
    @Log(title = "消息接收记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysMessageRecord sysMessageRecord)
    {
        return toAjax(sysMessageRecordService.insertSysMessageRecord(sysMessageRecord));
    }

    /**
     * 修改消息接收记录
     */
    @PreAuthorize("@ss.hasPermi('system:sysMessageRecord:edit')")
    @Log(title = "消息接收记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysMessageRecord sysMessageRecord)
    {
        return toAjax(sysMessageRecordService.updateSysMessageRecord(sysMessageRecord));
    }

    /**
     * 删除消息接收记录
     */
    @PreAuthorize("@ss.hasPermi('system:sysMessageRecord:remove')")
    @Log(title = "消息接收记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{messageRecordIds}")
    public AjaxResult remove(@PathVariable Long[] messageRecordIds)
    {
        return toAjax(sysMessageRecordService.deleteSysMessageRecordByMessageRecordIds(messageRecordIds));
    }
}
